@@ -1,7 +1,7 @@
 """avgper 과 yieldgap 계산
 """
 import math
-from db_hj3415 import mongo2
+from db_hj3415 import mongo2, dbpath
 from eval_hj3415 import eval
 from util_hj3415 import utils
 
@@ -18,7 +18,7 @@ def avg_per() -> float:
     # 가중조화평균으로 평균 per 산출 mi db에 저장
     per_r_cap_all = []
     cap_all = []
-    eval_list = eval.make_today_eval_df().to_dict('records')
+    eval_list = eval.make_today_eval_df(dbpath.load()).to_dict('records')
     for data in eval_list:
         # eval data: {'code': '111870', '종목명': 'KH 일렉트론', '주가': 1070, 'PER': -2.28, 'PBR': 0.96,
         # '시가총액': 103300000000, 'RED': -11055.0, '주주수익률': -7.13, '이익지표': -0.30426, 'ROIC': -40.31,
