@@ -1,5 +1,4 @@
-from db_hj3415 import mongo2
-from scraper_hj3415.db_path import MONGO_ADDR
+from db_hj3415 import mongo2, dbpath
 
 import logging
 logger = logging.getLogger(__name__)
@@ -13,7 +12,7 @@ logger.setLevel(logging.INFO)
 
 
 class Mongo2Pipeline:
-    client = mongo2.connect_mongo(MONGO_ADDR)
+    client = mongo2.connect_mongo(dbpath.load())
 
     # 몽고 데이터 베이스에 저장하는 파이프라인
     def process_item(self, item, spider):
