@@ -14,7 +14,7 @@ from nfs.spiders import common
 class C106Spider(scrapy.Spider):
     name = 'c106'
     allowed_domains = ['navercomp.wisereport.co.kr']
-    WAIT = 1.5
+    WAIT = 2
 
     def __init__(self, code):
         super().__init__()
